@@ -27,6 +27,7 @@ __all__ = (
     "AnomalyScoreTypeDef",
     "AnomalySubscriptionTypeDef",
     "AnomalyTypeDef",
+    "CostCategoryInheritedValueDimensionTypeDef",
     "CostCategoryProcessingStatusTypeDef",
     "CostCategoryReferenceTypeDef",
     "CostCategoryRuleTypeDef",
@@ -197,6 +198,12 @@ class AnomalyTypeDef(_RequiredAnomalyTypeDef, _OptionalAnomalyTypeDef):
     pass
 
 
+CostCategoryInheritedValueDimensionTypeDef = TypedDict(
+    "CostCategoryInheritedValueDimensionTypeDef",
+    {"DimensionName": Literal["LINKED_ACCOUNT_NAME", "TAG"], "DimensionKey": str},
+    total=False,
+)
+
 CostCategoryProcessingStatusTypeDef = TypedDict(
     "CostCategoryProcessingStatusTypeDef",
     {"Component": Literal["COST_EXPLORER"], "Status": Literal["PROCESSING", "APPLIED"]},
@@ -213,12 +220,20 @@ CostCategoryReferenceTypeDef = TypedDict(
         "NumberOfRules": int,
         "ProcessingStatus": List["CostCategoryProcessingStatusTypeDef"],
         "Values": List[str],
+        "DefaultValue": str,
     },
     total=False,
 )
 
 CostCategoryRuleTypeDef = TypedDict(
-    "CostCategoryRuleTypeDef", {"Value": str, "Rule": Dict[str, Any]}
+    "CostCategoryRuleTypeDef",
+    {
+        "Value": str,
+        "Rule": Dict[str, Any],
+        "InheritedValue": "CostCategoryInheritedValueDimensionTypeDef",
+        "Type": Literal["REGULAR", "INHERITED_VALUE"],
+    },
+    total=False,
 )
 
 _RequiredCostCategoryTypeDef = TypedDict(
@@ -233,7 +248,11 @@ _RequiredCostCategoryTypeDef = TypedDict(
 )
 _OptionalCostCategoryTypeDef = TypedDict(
     "_OptionalCostCategoryTypeDef",
-    {"EffectiveEnd": str, "ProcessingStatus": List["CostCategoryProcessingStatusTypeDef"]},
+    {
+        "EffectiveEnd": str,
+        "ProcessingStatus": List["CostCategoryProcessingStatusTypeDef"],
+        "DefaultValue": str,
+    },
     total=False,
 )
 
